@@ -3,10 +3,11 @@ from disk import Path
 from .Cache import Cache
 
 
-def memoize(path, exclude_kwargs=None, s3=None, spark=None, id=0, echo=1):
+def memoize(path, n_jobs, exclude_kwargs=None, s3=None, spark=None, id=0, echo=1):
 	"""
 	makes a decorator for memoizing a function
 	:type path: amazonian.S3.S3Path or Path or str
+	:type n_jobs: int
 	:type id: int
 	:type exclude_kwargs: list or tuple
 	:type s3: amazonian.S3.S3
@@ -31,7 +32,7 @@ def memoize(path, exclude_kwargs=None, s3=None, spark=None, id=0, echo=1):
 		:type function: callable
 		:rtype: callable
 		"""
-		cache = Cache(path=path, spark=spark, echo=echo)
+		cache = Cache(path=path, n_jobs=n_jobs, spark=spark, echo=echo)
 
 		if not isinstance(exclude_kwargs, (list, tuple)) and exclude_kwargs is not None:
 			raise TypeError(f'exclude_kwargs is of type {type(exclude_kwargs)}! None, list, and tuple are accepted.')
